@@ -710,7 +710,9 @@ tail_html (void) {
   if (json == NULL)
     return;
 
+  pthread_mutex_lock (&gwswriter->mutex);
   broadcast_holder (gwswriter->fd, json, strlen (json));
+  pthread_mutex_unlock (&gwswriter->mutex);
   free (json);
 }
 
@@ -804,8 +806,8 @@ verify_inode (FILE * fp, GLog * glog) {
 
 /* Process appended log data
  *
- * If nothing changed, 1 is returned.
- * If log file changed, 0 is returned. */
+ * If nothing changed, 0 is returned.
+ * If log file changed, 1 is returned. */
 static int
 perform_tail_follow (GLog * glog) {
   FILE *fp = NULL;
@@ -817,7 +819,7 @@ perform_tail_follow (GLog * glog) {
     parse_tail_follow (glog, glog->pipe);
     /* did we read something from the pipe? */
     if (0 == glog->bytes)
-      return 1;
+      return 0;
 
     glog->length += glog->bytes;
     goto out;
@@ -829,7 +831,7 @@ perform_tail_follow (GLog * glog) {
   /* ###NOTE: This assumes the log file being read can be of smaller size, e.g.,
    * rotated/truncated file or larger when data is appended */
   if (length == glog->length)
-    return 1;
+    return 0;
 
   if (!(fp = fopen (glog->filename, "r")))
     FATAL ("Unable to read the specified log file '%s'. %s", glog->filename, strerror (errno));
@@ -864,13 +866,7 @@ perform_tail_follow (GLog * glog) {
 
 out:
 
-  if (!conf.output_stdout) {
-    tail_term ();
-  } else {
-    tail_html ();
-  }
-
-  return 0;
+  return 1;
 }
 
 /* Loop over and perform a follow for the given logs */
@@ -880,14 +876,18 @@ tail_loop_html (Logs * logs) {
     .tv_sec = conf.html_refresh ? conf.html_refresh : HTML_REFRESH,
     .tv_nsec = 0,
   };
-  int i = 0;
+  int i = 0, ret = 0;
 
   while (1) {
     if (conf.stop_processing)
       break;
 
-    for (i = 0; i < logs->size; ++i)
-      perform_tail_follow (&logs->glog[i]);     /* 0.2 secs */
+    for (i = 0, ret = 0; i < logs->size; ++i)
+      ret |= perform_tail_follow (&logs->glog[i]);      /* 0.2 secs */
+
+    if (1 == ret)
+      tail_html ();
+
     if (nanosleep (&refresh, NULL) == -1 && errno != EINTR)
       FATAL ("nanosleep: %s", strerror (errno));
   }
@@ -983,17 +983,18 @@ static void
 term_tail_logs (Logs * logs) {
   struct timespec ts = {.tv_sec = 0,.tv_nsec = 200000000 };     /* 0.2 seconds */
   uint32_t offset = 0;
-  int i;
+  int i, ret;
 
-  for (i = 0; i < logs->size; ++i) {
-    if (perform_tail_follow (&logs->glog[i]) != 0)
-      continue;
+  for (i = 0, ret = 0; i < logs->size; ++i)
+    ret |= perform_tail_follow (&logs->glog[i]);
 
+  if (1 == ret) {
+    tail_term ();
     offset = *logs->processed - logs->offset;
     render_screens (offset);
-    if (nanosleep (&ts, NULL) == -1 && errno != EINTR) {
-      FATAL ("nanosleep: %s", strerror (errno));
-    }
+  }
+  if (nanosleep (&ts, NULL) == -1 && errno != EINTR) {
+    FATAL ("nanosleep: %s", strerror (errno));
   }
 }
 
