@@ -948,6 +948,13 @@ parse_specifier (GLogItem * logitem, char **str, const char *p, const char *end)
       free (tkn);
       return 1;
     }
+    /* require a valid host token (e.g., ord38s18-in-f14.1e100.net) even when we're
+     * not validating the IP */
+    if (conf.no_ip_validation && *tkn == '\0') {
+      spec_err (logitem, SPEC_TOKN_INV, *p, tkn);
+      free (tkn);
+      return 1;
+    }
     logitem->host = tkn;
     break;
     /* request method */
@@ -1521,11 +1528,13 @@ ignore_static (const char *req) {
  * If the request is a 404, 1 is returned. */
 static int
 is_404 (GLogItem * logitem) {
+  if (!logitem->status || *logitem->status == '\0')
+    return 0;
   /* is this a 404? */
-  if (logitem->status && !memcmp (logitem->status, "404", 3))
+  if (!memcmp (logitem->status, "404", 3))
     return 1;
   /* treat 444 as 404? */
-  else if (logitem->status && !memcmp (logitem->status, "444", 3) && conf.code444_as_404)
+  else if (!memcmp (logitem->status, "444", 3) && conf.code444_as_404)
     return 1;
   return 0;
 }
