@@ -871,7 +871,7 @@ load_host_agents (const char *addr) {
   GAgents *agents = NULL;
   GSLList *keys = NULL, *list = NULL;
   void *data = NULL;
-  uint32_t items = 4, key = djb2 ((unsigned char *) addr);
+  uint32_t items = 4, key = djb2 ((const unsigned char *) addr);
 
   keys = ht_get_keymap_list_from_key (HOSTS, key);
   if (!keys)
@@ -1297,12 +1297,13 @@ render_confdlg (Logs * logs, GSpinner * spinner) {
     "Common Log Format (CLF)",
     "Common Log Format (CLF) with Virtual Host",
     "W3C",
-    "Squid Native Format",
     "CloudFront (Download Distribution)",
     "Google Cloud Storage",
     "AWS Elastic Load Balancing (HTTP/S)",
+    "Squid Native Format",
     "AWS Simple Storage Service (S3)",
     "CADDY JSON Structured",
+    "AWS Application Load Balancer",
   };
   n = ARRAY_SIZE (choices);
   getmaxyx (stdscr, y, x);
