@@ -99,7 +99,7 @@ int str_to_time (const char *str, const char *fmt, struct tm *tm);
 int valid_output_type (const char *filename);
 off_t file_size (const char *filename);
 size_t append_str (char **dest, const char *src);
-uint32_t djb2(unsigned char *str);
+uint32_t djb2(const unsigned char *str);
 uint32_t ip_to_binary (const char *ip);
 void genstr(char *dest, size_t len);
 void strip_newlines (char *str);
